@@ -9,21 +9,27 @@ except PackageNotFoundError:  # pragma: no cover
 finally:
     del version, PackageNotFoundError
 
-from .base import Configuration, MimeTypes, SteamshipError
+from .base import (
+    Configuration,
+    MimeTypes,
+    RuntimeEnvironments,
+    SteamshipError,
+    Task,
+    TaskState,
+    check_environment,
+)
 from .data import (
-    App,
-    AppInstance,
-    AppVersion,
     Block,
     DocTag,
     EmbeddingIndex,
     File,
+    Package,
+    PackageInstance,
+    PackageVersion,
     PluginInstance,
     PluginVersion,
-    Space,
     Tag,
-    TagKind,
-    TextTag,
+    Workspace,
 )
 
 from .client import Steamship  # isort:skip
@@ -33,17 +39,19 @@ __all__ = [
     "Configuration",
     "SteamshipError",
     "MimeTypes",
-    "App",
-    "AppInstance",
-    "AppVersion",
+    "Package",
+    "PackageInstance",
+    "PackageVersion",
     "File",
+    "Task",
+    "TaskState",
     "Block",
     "Tag",
-    "Space",
+    "Workspace",
     "PluginInstance",
     "PluginVersion",
-    "TagKind",
-    "TextTag",
     "DocTag",
     "EmbeddingIndex",
+    "check_environment",
+    "RuntimeEnvironments",
 ]
