@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from steamship.base.configuration import CamelModel
+from steamship.base.model import CamelModel
 from steamship.data.file import File
 
 
 class BlockAndTagPluginOutput(CamelModel):
-    file: File.CreateRequest = None
+    file: File = None
