@@ -4,8 +4,8 @@ from typing import Any, Dict
 
 from assets.plugins.blockifiers.csv_blockifier import CsvBlockifier
 
-from steamship.app import create_handler
-from steamship.plugin.blockifier import Blockifier
+from steamship.invocable import InvocationContext, create_handler
+from steamship.plugin.blockifier.blockifier import Blockifier
 
 
 class TsvBlockifier(CsvBlockifier, Blockifier):
@@ -14,8 +14,10 @@ class TsvBlockifier(CsvBlockifier, Blockifier):
     Implementation is only here to demonstrate how plugins can be built through inheritance.
     """
 
-    def __init__(self, client=None, config: Dict[str, Any] = None):
-        super().__init__(client, config)
+    def __init__(
+        self, client=None, config: Dict[str, Any] = None, context: InvocationContext = None
+    ):
+        super().__init__(client, config, context)
         self.config.delimiter = "\t"
 
 
