@@ -1,12 +1,9 @@
-from typing import Type
-
 from steamship import MimeTypes
-from steamship.app import Response, create_handler
-from steamship.plugin.config import Config
+from steamship.invocable import InvocableResponse, create_handler
+from steamship.invocable.plugin_service import PluginRequest
 from steamship.plugin.file_importer import FileImporter
 from steamship.plugin.inputs.file_import_plugin_input import FileImportPluginInput
 from steamship.plugin.outputs.raw_data_plugin_output import RawDataPluginOutput
-from steamship.plugin.service import PluginRequest
 
 # Note: this aligns with the same document in the internal Engine test.
 HANDLE = "test-importer-plugin-v1"
@@ -18,15 +15,11 @@ TEST_DOC = f"# {TEST_H1}\n\n{TEST_S1} {TEST_S2}\n\n{TEST_S3}\n"
 
 
 class TestFileImporterPlugin(FileImporter):
-    class EmptyConfig(Config):
-        pass
-
-    def config_cls(self) -> Type[Config]:
-        return self.EmptyConfig
-
-    def run(self, request: PluginRequest[FileImportPluginInput]) -> Response[RawDataPluginOutput]:
+    def run(
+        self, request: PluginRequest[FileImportPluginInput]
+    ) -> InvocableResponse[RawDataPluginOutput]:
         bytes = (100000 * TEST_DOC).encode("utf-8")
-        return Response(data=RawDataPluginOutput(_bytes=bytes, mime_type=MimeTypes.MKD))
+        return InvocableResponse(data=RawDataPluginOutput(_bytes=bytes, mime_type=MimeTypes.MKD))
 
 
 handler = create_handler(TestFileImporterPlugin)
