@@ -10,4 +10,4 @@ from pathlib import Path
 # Make sure `steamship_tests` is on the PYTHONPATH. Otherwise cross-test imports (e.g. to util libraries) will fail.
 sys.path.append(str(Path(__file__).parent.absolute()))
 
-from steamship_tests.utils.fixtures import app_handler, client  # noqa: F401, E402
+from steamship_tests.utils.fixtures import client, invocable_handler  # noqa: F401, E402
