@@ -10,7 +10,6 @@ def test_e2e_tagger():
         test_doc = "Hi there"
         res = instance.tag(doc=test_doc)
         res.wait()
-        assert res.error is None
-        assert res.data is not None
-        assert len(res.data.file.blocks) == 1
-        assert res.data.file.blocks[0].text == test_doc
+        assert res.output is not None
+        assert len(res.output.file.blocks) == 1
+        assert res.output.file.blocks[0].text == test_doc
